starcluster.commands.runplugin.CmdRunPlugin

Package starcluster :: Package commands :: Module runplugin :: Class CmdRunPlugin |
[hide private]
[frames] | no frames]

# Class CmdRunPlugin

source code

    runplugin <plugin_name> <cluster_tag>

    Run a StarCluster plugin on a runnning cluster

    plugin_name - name of plugin section defined in the config
    cluster_tag - tag name of a running StarCluster

    Example:

       $ starcluster runplugin myplugin mycluster

Instance Methods | [hide private]
execute(self, args) | source code
Inherited from `base.CmdBase`: `addopts`, `cancel_command`, `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| names = ``[``'``runplugin``'``,` `'``rp``'``]``
Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cfg`, `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`